@@ -18,14 +18,9 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
-from aliyunsdksas.endpoint import endpoint_data
 
 class DescribeHoneyPotAuthRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'DescribeHoneyPotAuth','sas')
-		self.set_method('POST')
-		if hasattr(self, "endpoint_map"):
-			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
-		if hasattr(self, "endpoint_regional"):
-			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+		self.set_method('POST')
\ No newline at end of file
