@@ -18,18 +18,12 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
-from aliyunsdksas.endpoint import endpoint_data
 
 class DescribeImageVulListRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'DescribeImageVulList','sas')
 		self.set_method('POST')
-		if hasattr(self, "endpoint_map"):
-			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
-		if hasattr(self, "endpoint_regional"):
-			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
-
 
 	def get_Type(self):
 		return self.get_query_params().get('Type')
@@ -97,6 +91,12 @@ class DescribeImageVulListRequest(RpcRequest):
 	def set_TargetType(self,TargetType):
 		self.add_query_param('TargetType',TargetType)
 
+	def get_RepoNamespace(self):
+		return self.get_query_params().get('RepoNamespace')
+
+	def set_RepoNamespace(self,RepoNamespace):
+		self.add_query_param('RepoNamespace',RepoNamespace)
+
 	def get_ContainerFieldValue(self):
 		return self.get_query_params().get('ContainerFieldValue')
 
@@ -137,4 +137,16 @@ class DescribeImageVulListRequest(RpcRequest):
 		return self.get_query_params().get('RepoName')
 
 	def set_RepoName(self,RepoName):
-		self.add_query_param('RepoName',RepoName)
\ No newline at end of file
+		self.add_query_param('RepoName',RepoName)
+
+	def get_RepoInstanceId(self):
+		return self.get_query_params().get('RepoInstanceId')
+
+	def set_RepoInstanceId(self,RepoInstanceId):
+		self.add_query_param('RepoInstanceId',RepoInstanceId)
+
+	def get_RepoRegionId(self):
+		return self.get_query_params().get('RepoRegionId')
+
+	def set_RepoRegionId(self,RepoRegionId):
+		self.add_query_param('RepoRegionId',RepoRegionId)
\ No newline at end of file
