@@ -18,18 +18,12 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
-from aliyunsdksas.endpoint import endpoint_data
 
 class HandleSecurityEventsRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'HandleSecurityEvents','sas')
 		self.set_method('POST')
-		if hasattr(self, "endpoint_map"):
-			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
-		if hasattr(self, "endpoint_regional"):
-			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
-
 
 	def get_MarkMissParam(self):
 		return self.get_query_params().get('MarkMissParam')
@@ -67,4 +61,10 @@ class HandleSecurityEventsRequest(RpcRequest):
 		return self.get_query_params().get('OperationParams')
 
 	def set_OperationParams(self,OperationParams):
-		self.add_query_param('OperationParams',OperationParams)
\ No newline at end of file
+		self.add_query_param('OperationParams',OperationParams)
+
+	def get_MarkBatch(self):
+		return self.get_query_params().get('MarkBatch')
+
+	def set_MarkBatch(self,MarkBatch):
+		self.add_query_param('MarkBatch',MarkBatch)
\ No newline at end of file
